#include <vcl.h>
#include <inifiles.hpp>
#include <stdio.h>
#pragma hdrstop
#include "tedi_main.h"
#include "tedi_ini.h"
//==============================================================================
EditOptions::EditOptions()
{
 font_color = (TColor)RGB(0x00,191,0x00);
 font_name = "Lucida Console";
 font_size = 11;
 font_height = -15;
 font_pitch = (TFontPitch)fpDefault;
 font_bold = false;
 font_italic = false;
 font_underline = false;
 font_strike = false;

 readonly = false;
 background = clBlack;
 form_style = false; //fsNormal
 top = 104;
 left = 225;
 wordwrap = false;
 window_state = wsNormal;
 tool_bar = true;
 status_bar = true;
 vertical_scroll = true;
}
//==============================================================================
void EditOptions::OnEnterRichEdit()
{
 Form1->RichEdit1->Font->Color = font_color;
 Form1->RichEdit1->Font->Name = font_name;
 Form1->RichEdit1->Font->Size = font_size;
 Form1->RichEdit1->Font->Height = font_height;
 Form1->RichEdit1->Font->Pitch = font_pitch;
 if(font_bold) Form1->RichEdit1->Font->Style = TFontStyles()<< fsBold;
 if(font_italic) Form1->RichEdit1->Font->Style = TFontStyles()<< fsItalic;
 if(font_underline) Form1->RichEdit1->Font->Style = TFontStyles()<< fsUnderline;
 if(font_strike) Form1->RichEdit1->Font->Style = TFontStyles()<< fsStrikeOut;
 Form1->RichEdit1->ReadOnly = readonly;
}
//==============================================================================
void EditOptions::OnCreateForm()
{
 Form1->RichEdit1->Color = background;
 Form1->bReadOnly->Down = readonly;
 Form1->mReadOnly->Checked = readonly;
 Form1->mKeepOnTop->Checked = (form_style)?true:false;
 Form1->FormStyle = (form_style)? fsStayOnTop : fsNormal;
 Form1->Top = top;
 Form1->Left = left;
 Form1->mWordWrap->Checked = wordwrap;
 Form1->RichEdit1->WordWrap = wordwrap;//Note: No set WordWarp in OnEnter RichEdit!
 Form1->WindowState = (TWindowState)window_state;

 Form1->mToolbar->Checked = tool_bar;
 Form1->ToolBar1->Visible = tool_bar;

 Form1->mStatusBar->Checked = status_bar;
 Form1->StatusBar1->Visible = status_bar;

 Form1->mScrollBarVertical->Checked = vertical_scroll;
 Form1->RichEdit1->ScrollBars = (vertical_scroll)? ssVertical : ssNone;
}
//==============================================================================
void EditOptions::IniFileCreate()
{
 AnsiString file = ChangeFileExt(Application->ExeName,".INI");
 file = file.LowerCase();
 if(!FileExists(file))
 {
  FILE *f = fopen(file.c_str(),"wt");
  if(f!=NULL) fclose(f);
 }
}
//==============================================================================
void EditOptions::IniFileRead()
{
 AnsiString file = ChangeFileExt(Application->ExeName,".INI");
 file = file.LowerCase();
 if(FileExists(file))
 {
  TIniFile *ini;
  ini = new TIniFile(file);
  //----------------------------------------------------------------------------
  font_color = (Graphics::TColor)
               ini->ReadInteger("Font","Color",(TColor)RGB(0x00,191,0x00));
  //----------------------------------------------------------------------------
  font_name = ini->ReadString("Font","Name","Lucida Console");
  //----------------------------------------------------------------------------
  font_size = ini->ReadInteger("Font","Size",11);
  font_height = ini->ReadInteger("Font","Height",-15);
  font_pitch = (TFontPitch)ini->ReadInteger( "Font", "Pitch",fpDefault);
  //----------------------------------------------------------------------------
  font_bold = ini->ReadBool( "Font", "StyleBold",false);
  font_italic = ini->ReadBool( "Font", "StyleItalic",false);
  font_underline = ini->ReadBool( "Font", "StyleUnderline",false);
  font_strike = ini->ReadBool( "Font", "StyleStrike",false);
  //----------------------------------------------------------------------------
  readonly = ini->ReadBool("Options","ReadOnly",false);
  //----------------------------------------------------------------------------
  background = (Graphics::TColor)ini->ReadInteger("Options","Background",0);
  //----------------------------------------------------------------------------
  top = ini->ReadInteger("Options","Top",104);
  left = ini->ReadInteger("Options","Left",225);
  //----------------------------------------------------------------------------
  wordwrap = ini->ReadBool("Options","WordWrap",false);
  //----------------------------------------------------------------------------
  form_style = ini->ReadInteger("Options","KeepOnTop",false);
  //----------------------------------------------------------------------------
  window_state = ini->ReadInteger("Options","WindowState",wsNormal);
  //----------------------------------------------------------------------------
  tool_bar = ini->ReadBool("Options","ToolBar",true);
  status_bar = ini->ReadBool("Options","StatusBar",true);
  vertical_scroll = ini->ReadBool("Options","VScroll",true);
  //----------------------------------------------------------------------------
  delete ini;
 }
}
//==============================================================================
void EditOptions::IniFileWrite()
{
 AnsiString file = ChangeFileExt(Application->ExeName,".INI");
 file = file.LowerCase();
 AnsiString msg;
 if(FileExists(file))
 {
  TIniFile *ini;
  ini = new TIniFile(file);
  //----------------------------------------------------------------------------
  ini->WriteInteger( "Font", "Color", Form1->RichEdit1->Font->Color);
  ini->WriteString( "Font", "Name", Form1->RichEdit1->Font->Name);
  ini->WriteInteger( "Font", "Size", Form1->RichEdit1->Font->Size);
  ini->WriteInteger( "Font", "Height", Form1->RichEdit1->Font->Height);
  ini->WriteInteger( "Font", "Pitch", Form1->RichEdit1->Font->Pitch);
  //----------------------------------------------------------------------------
  bool bold = (Form1->RichEdit1->Font->Style.Contains(fsBold))?true:false;
  bool italic = (Form1->RichEdit1->Font->Style.Contains(fsItalic))?true:false;
  bool underline = (Form1->RichEdit1->Font->Style.Contains(fsUnderline))?true:false;
  bool strike = (Form1->RichEdit1->Font->Style.Contains(fsStrikeOut))?true:false;
  //----------------------------------------------------------------------------
  ini->WriteBool( "Font", "StyleBold",bold);
  ini->WriteBool( "Font", "StyleItalic",italic);
  ini->WriteBool( "Font", "StyleUnderline",underline);
  ini->WriteBool( "Font", "StyleStrike",strike);
  //----------------------------------------------------------------------------
  ini->WriteBool("Options","ReadOnly",Form1->bReadOnly->Down);
  ini->WriteInteger("Options","Background",Form1->RichEdit1->Color);
  ini->WriteInteger("Options","Top",Form1->Top);
  ini->WriteInteger("Options","Left",Form1->Left);
  //----------------------------------------------------------------------------
  ini->WriteInteger("Options","WordWrap",Form1->RichEdit1->WordWrap);
  //----------------------------------------------------------------------------
  ini->WriteBool("Options","KeepOnTop",Form1->mKeepOnTop->Checked);
  //----------------------------------------------------------------------------
  ini->WriteInteger("Options","WindowState",Form1->WindowState);
  //----------------------------------------------------------------------------
  ini->WriteBool("Options","ToolBar",Form1->mToolbar->Checked);
  ini->WriteBool("Options","StatusBar",Form1->mStatusBar->Checked);
  ini->WriteBool("Options","VScroll",Form1->mScrollBarVertical->Checked);
  //----------------------------------------------------------------------------
  ini->UpdateFile();
  delete ini;
  //----------------------------------------------------------------------------
  msg = "Ok save settings!";
  Application->MessageBox(msg.c_str(), "Information",MB_OK|MB_ICONINFORMATION);
 }
 else
 {
  msg = "File: " + file + " - not exist";
  Application->MessageBox(msg.c_str(), "Information",MB_OK|MB_ICONEXCLAMATION);
 }
}
//==============================================================================



